@@ -3,7 +3,7 @@ from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from typing import Any, List
-    from .safety import NotebookSafety
+    from nbsafety.safety import NotebookSafety
 
 
 # USAGE = """Options:
@@ -21,12 +21,6 @@ show_dependency <variable_name> <variable_name2> ...:
 show_stale: 
     - This will print out all the global variables that are stale. 
 
-set_disable_level <integer>:
-    - level 0: Warning,    Stop Code,   Record new dependencies, (Full functionality)
-    - level 1: Warning,    Run code,    Record new dependencies, (Don't stop at the warning)
-    - level 2: No Warning, Run code,    Record new dependencies, (Don't show warnings)
-    - level 3: No warning, Run cocde,   No new dependencies,     (Original Kernel)
-
 remove_dependency <parent_name> <child_name>:
     - This will remove the dependency between parent variable and the child variable.
 
@@ -37,7 +31,6 @@ turn_off_warnings_for  <variable_name> <variable_name2> ...:
     - This will turn off the warnings for given global variables. These variables will not be
       considered as stale anymore. Multiple variables should be separated with spaces.
 
-
 turn_off_warnings_for  <variable_name> <variable_name2> ...: 
     - This will turn the warnings back on for given global variables. These variables could have
       stale dependencies now. Multiple variables should be separated with spaces."""
@@ -71,7 +64,7 @@ def show_stale(safety: 'NotebookSafety', line: 'List[str]'):
     stale_set = set()
     for dsym_set in dsym_sets:
         for data_sym in dsym_set:
-            if data_sym.has_stale_ancestor:
+            if data_sym.is_stale:
                 stale_set.add(data_sym)
     if not stale_set:
         print("No DataSymbol has stale dependency for now!")
@@ -81,30 +74,11 @@ def show_stale(safety: 'NotebookSafety', line: 'List[str]'):
         print("DataSymbols with stale dependencies are:", [str(n) for n in stale_set])
 
 
-def set_disable_level(safety: 'NotebookSafety', line: 'List[str]'):
-    if len(line) != 2 or line[1] not in ['0', '1', '2', '3']:
-        print("""Usage: %safety set_disable_level <integer>
--level 0: Warning,    Stop Code,   Record new dependencies, (Full functionality)
--level 1: Warning,    Run code,    Record new dependencies, (Don't stop at the warning)
--level 2: No Warning, Run code,    Record new dependencies, (Don't show warnings)
--level 3: No warning, Run cocde,   No new dependencies,     (Original Kernel)""")
-        return
-    safety._disable_level = int(line[1])
-
-
-def set_propagation(safety: 'NotebookSafety', line: 'List[str]'):
-    if len(line) != 2 or line[1] not in ['cells', 'always']:
-        print('Usage: %safety set_propagation [cells | always]')
-        # TODO: complete explanation
-        return
-    safety.no_stale_propagation_for_same_cell_definition = (line[1] == 'cells')
-
-
 def trace_messages(safety: 'NotebookSafety', line: 'List[str]'):
     if len(line) != 2:
         print("Usage: %safety trace_messages [enabled|disabled] ...")
         return
-    safety.trace_messages_enabled = (line[1].lower().startswith("enable"))
+    safety.config.trace_messages_enabled = (line[1].lower().startswith("enable"))
 
 
 def remove_dep(safety: 'NotebookSafety', line: 'List[str]'):
@@ -119,10 +93,11 @@ def remove_dep(safety: 'NotebookSafety', line: 'List[str]'):
     if not child_data_sym:
         print("Cannot find DataSymbol", line[2])
         return
-    if child_data_sym not in parent_data_sym.children or parent_data_sym not in child_data_sym.parents:
+    if parent_data_sym not in child_data_sym.parents:
         print("Two DataSymbols do not have a dependency relation")
         return
-    parent_data_sym.children.remove(child_data_sym)
+    for children in parent_data_sym.children_by_cell_position.values():
+        children.remove(child_data_sym)
     child_data_sym.parents.remove(parent_data_sym)
 
 
@@ -138,10 +113,10 @@ def add_dep(safety: 'NotebookSafety', line: 'List[str]'):
     if not child_data_sym:
         print("Cannot find DataSymbol", line[2])
         return
-    if child_data_sym in parent_data_sym.children and parent_data_sym in child_data_sym.parents:
+    if parent_data_sym in child_data_sym.parents:
         print("Two DataSymbols already have a dependency relation")
         return
-    parent_data_sym.children.add(child_data_sym)
+    parent_data_sym.children_by_cell_position[-1].add(child_data_sym)
     child_data_sym.parents.add(parent_data_sym)
 
 
@@ -152,7 +127,7 @@ def turn_off_warnings_for(safety: 'NotebookSafety', line: 'List[str]'):
     for data_sym_name in line[1:]:
         data_sym = safety.global_scope.lookup_data_symbol_by_name(data_sym_name)
         if data_sym:
-            data_sym.no_warning = True
+            data_sym.disable_warnings = True
             print("Warnings are turned off for", data_sym_name)
         else:
             print("Cannot find DataSymbol", data_sym_name)
@@ -165,7 +140,7 @@ def turn_on_warnings_for(safety: 'NotebookSafety', line: 'List[str]'):
     for data_sym_name in line[1:]:
         data_sym = safety.global_scope.lookup_data_symbol_by_name(data_sym_name)
         if data_sym:
-            data_sym.no_warning = False
+            data_sym.disable_warnings = False
             print("Warnings are turned on for", data_sym_name)
         else:
             print("Cannot find DataSymbol", data_sym_name)
