@@ -524,50 +524,31 @@ class TracingManager(object):
         finally:
             self._disable_tracing(check_enabled=False)
 
-    def _attempt_to_reenable_tracing(self, frame: 'FrameType'):
-        assert self.tracing_reset_pending
+    def _attempt_to_reenable_tracing(self, frame: 'FrameType') -> None:
+        if self.safety.is_develop:
+            assert self.tracing_reset_pending, 'expected tracing reset to be pending!'
+            assert self.call_depth > 0, 'expected managed call depth > 0, got %d' % self.call_depth
         self.tracing_reset_pending = False
         call_depth = 0
         while frame is not None:
             if frame.f_code.co_filename.startswith('<ipython-input'):
                 call_depth += 1
             frame = frame.f_back
-        # put us back in a good self given weird way notebook executes code
-        if call_depth == 1 and self.call_depth == 0:
-            self.call_depth = 1
-        while self.call_depth > call_depth:
-            self.call_depth -= 1
-            self._stack.pop()
-        while len(self.nested_call_stack) > 0:
-            self.nested_call_stack.pop()
-        if call_depth != self.call_depth:
-            # TODO: also check that the stacks agree with each other beyond just size
-            # logger.warning('reenable tracing failed: %d vs %d', call_depth, self.call_depth)
+        if self.safety.is_develop:
+            assert call_depth >= 1, 'expected call depth >= 1, got %d' % call_depth
+        # TODO: allow reenabling tracing beyond just at the top level
+        if call_depth != 1:
             self._disable_tracing()
-        # else:
-        #     logger.warning('reenable tracing: %d vs %d', call_depth, self.call_depth)
-        return None
-        # TODO: eventually we'd like to reenable tracing even when the call depth isn't mismatched
-        # scopes_to_push = []
-        # while frame is not None:
-        #     if frame.f_code.co_filename.startswith('<ipython-input'):
-        #         call_depth += 1
-        #         fun_name = frame.f_code.co_name
-        #         if fun_name == '<module>':
-        #             if self.call_depth == 0:
-        #                 self.call_depth = 1
-        #             break
-        #         cell_num, lineno = TraceState.get_position(frame)
-        #         stmt_node = safety.selfment_cache[cell_num][lineno]
-        #         func_cell = self.safety.selfment_to_func_cell[id(stmt_node)]
-        #         scopes_to_push.append(func_cell.call_scope)
-        #     frame = frame.f_back
-        # scopes_to_push.reverse()
-        # scopes_to_push = scopes_to_push[self.call_depth-1:]
-        # for scope in scopes_to_push:
-        #     self.push_stack(scope)
-        # self.call_depth = call_depth
-        # return None
+            return
+        # at this point, we can be sure we're at the top level
+        # because tracing was enabled in a handler and not in the
+        # top level, we need to clear the stack, since we won't
+        # catch the return event
+        self.call_depth = 0
+        self._stack = []
+        self.nested_call_stack = []
+        if self.safety.config.trace_messages_enabled:
+            logger.warning('reenable tracing >>>')
 
     @on_exception_default_to(return_val(None, logger))
     def _sys_tracer(self, frame: 'FrameType', evt: 'Union[str, TraceEvent]', extra):
@@ -579,6 +560,7 @@ class TracingManager(object):
         if self.tracing_reset_pending:
             assert event == TraceEvent.call
             self._attempt_to_reenable_tracing(frame)
+            return None
 
         # notebook cells have filenames that appear as '<ipython-input...>'
         if frame.f_code.co_filename.startswith('<ipython-input'):
@@ -590,6 +572,7 @@ class TracingManager(object):
             return self._sys_tracer
 
         if event not in (TraceEvent.return_, TraceEvent.after_stmt) and not self.tracing_enabled:
+            logger.warning('skip %s', event)
             return None
 
         # IPython quirk -- every line in outer scope apparently wrapped in lambda
@@ -624,12 +607,11 @@ class TracingManager(object):
         if self.safety.config.trace_messages_enabled:
             codeline = astunparse.unparse(stmt_node).strip('\n').split('\n')[0]
             codeline = ' ' * getattr(stmt_node, 'col_offset', 0) + codeline
-            logger.warning(' %3d: %9s >>> %s', lineno, event, codeline)
+            logger.warning(' %3d: %10s >>> %s', lineno, event, codeline)
         if event == TraceEvent.call:
             if trace_stmt.call_seen:
-                self.call_depth -= 1
-                if self.call_depth == 1:
-                    self.call_depth = 0
+                if self.safety.config.trace_messages_enabled:
+                    logger.warning(' disable tracing >>>')
                 self._disable_tracing()
                 return None
             trace_stmt.call_seen = True
